@@ -16,9 +16,12 @@ details.
 
 ***/
 
+#include <stdlib.h>
 #include <asm/types.h>
+#include <sys/socket.h>
 #include <linux/if_ether.h>
 #include <linux/if_tr.h>
+#include <linux/netdevice.h>
 #include <linux/if_fddi.h>
 #include <winops.h>
 #include "arphdr.h"
