@@ -31,10 +31,10 @@ details.
 #include <netinet/tcp.h>
 #include <sys/time.h>
 #include <net/if_arp.h>
-#include <net/if.h>
 #include <sys/ioctl.h>
 #include <linux/if_packet.h>
 #include <linux/if_ether.h>
+#include <linux/netdevice.h>
 #include <linux/if_fddi.h>
 #include <linux/if_tr.h>
 #include <linux/isdn.h>
